@@ -8,7 +8,7 @@ import logging
 import requests
 import posixpath
 
-from six.moves.urllib.parse import urlparse
+from urllib.parse import urlparse
 
 from mediafire.api import (MediaFireApi, MediaFireApiError)
 from mediafire.uploader import (MediaFireUploader, UploadSession)
